==> estateplat-common-1.2.4-20210720.032357-816-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzHydjxxhy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/11/19
 * @description 省级信息共享-民政部-婚姻登记信息核验（个人）/（双方）接口
 */
@Table(name = "xxgx_mz_hydjxxhy")
public class XxgxMzHydjxxhy {
    @Id
    private String hyid;//主键
    private String gmsfzh;//公民身份证号
    private String gmxm;//公民姓名
    private String hyjg;//核验结果
    private String cxjg;//查询结果
    private String cxywlb;//查询业务类别
    private String proid;//项目ID
    private String qlrid;//权利人ID

    public String getHyid() {
        return hyid;
    }

    public void setHyid(String hyid) {
        this.hyid = hyid;
    }

    public String getGmsfzh() {
        return gmsfzh;
    }

    public void setGmsfzh(String gmsfzh) {
        this.gmsfzh = gmsfzh;
    }

    public String getGmxm() {
        return gmxm;
    }

    public void setGmxm(String gmxm) {
        this.gmxm = gmxm;
    }

    public String getHyjg() {
        return hyjg;
    }

    public void setHyjg(String hyjg) {
        this.hyjg = hyjg;
    }

    public String getCxjg() {
        return cxjg;
    }

    public void setCxjg(String cxjg) {
        this.cxjg = cxjg;
    }

    public String getCxywlb() {
        return cxywlb;
    }

    public void setCxywlb(String cxywlb) {
        this.cxywlb = cxywlb;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}

==> estateplat-common-1.2.4-20250303.022354-1293-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxMzHydjxxhy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020/11/19
 * @description 省级信息共享-民政部-婚姻登记信息核验（个人）/（双方）接口
 */
@Table(name = "xxgx_mz_hydjxxhy")
public class XxgxMzHydjxxhy {
    @Id
    private String hyid;//主键
    private String gmsfzh;//公民身份证号
    private String gmxm;//公民姓名
    private String mxm;//男方姓名
    private String msfzjh;//男方证件号
    private String wxm;//女方姓名
    private String wsfzjh;//女方证件号
    private String hyjg;//核验结果
    private String cxjg;//查询结果
    private String ywlxdm;//业务类型代码
    private String ywlxms;//业务类型描述
    private String djrq;//登记日期
    private String cxywlb;//查询业务类别
    private String proid;//项目ID
    private String qlrid;//权利人ID

    public String getHyid() {
        return hyid;
    }

    public void setHyid(String hyid) {
        this.hyid = hyid;
    }

    public String getGmsfzh() {
        return gmsfzh;
    }

    public void setGmsfzh(String gmsfzh) {
        this.gmsfzh = gmsfzh;
    }

    public String getGmxm() {
        return gmxm;
    }

    public void setGmxm(String gmxm) {
        this.gmxm = gmxm;
    }

    public String getHyjg() {
        return hyjg;
    }

    public void setHyjg(String hyjg) {
        this.hyjg = hyjg;
    }

    public String getMxm() {
        return mxm;
    }

    public void setMxm(String mxm) {
        this.mxm = mxm;
    }

    public String getMsfzjh() {
        return msfzjh;
    }

    public void setMsfzjh(String msfzjh) {
        this.msfzjh = msfzjh;
    }

    public String getWxm() {
        return wxm;
    }

    public void setWxm(String wxm) {
        this.wxm = wxm;
    }

    public String getWsfzjh() {
        return wsfzjh;
    }

    public void setWsfzjh(String wsfzjh) {
        this.wsfzjh = wsfzjh;
    }

    public String getCxjg() {
        return cxjg;
    }

    public void setCxjg(String cxjg) {
        this.cxjg = cxjg;
    }

    public String getCxywlb() {
        return cxywlb;
    }

    public void setCxywlb(String cxywlb) {
        this.cxywlb = cxywlb;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYwlxdm() {
        return ywlxdm;
    }

    public void setYwlxdm(String ywlxdm) {
        this.ywlxdm = ywlxdm;
    }

    public String getYwlxms() {
        return ywlxms;
    }

    public void setYwlxms(String ywlxms) {
        this.ywlxms = ywlxms;
    }

    public String getDjrq() {
        return djrq;
    }

    public void setDjrq(String djrq) {
        this.djrq = djrq;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }
}
